@@ -1,5 +1,5 @@
 (* approx: proxy server for Debian archive files
-   Copyright (C) 2008  Eric C. Cooper <ecc@cmu.edu>
+   Copyright (C) 2009  Eric C. Cooper <ecc@cmu.edu>
    Released under the GNU General Public License *)
 
 (* Translate a request URL to the remote repository URL and
@@ -7,13 +7,6 @@
 
 val translate_request : string -> string * string
 
-(* Extract the distribution and relative filename
-   from the absolute pathname of a file in the cache.
-   Example: split_pathname "/var/cache/approx/debian/pool/main/..."
-   returns ("debian", "pool/main/...") *)
-
-val split_cache_path : string -> string * string
-
 (* Find the remote URL corresponding to a given file in the cache,
    or raise Not_found if it does not correspond to a known mapping *)
 
